function [LGroups]=LGroups(P,Node,Cell2Vtx,Domain)
%
%  Compute the L-group for each face
%
NCell = size(Cell2Vtx,1);
NVtx  = size(Vtx2Edge,1);
NEdge = size(Edge2Vtx,1);
%
for ei=1:Nedge,
    v1=Edge2Vtx(ei,1);
    v2=Edge2Vtx(ei,2);
    % size of the L-group
    NLi = length(Vtx2Edge{v1})+length(Vtx2Edge{v2});
    % go over the ei's neighbours on v1's side
    for ej=Vtx2Edge{v1}(:)',
        % determine the "base element"
        Cijs = intersect(Edge2Cell{ei},Edge2Cell{ej});
        % it is possible that there is more than one base element
        for cij=Cijs(:)',
            % form the linear system for grad reconstruction
            A=[formRowA(cij,ei,P,Node,Edge2Vtx,Cell2Edge); ...
               formRowA(cij,ej,P,Node,Edge2Vtx,Cell2Edge)];
            % calculate the norm ||A^{-1}|| and check whether
            % this is our "optimal" group for the edge or not
        end
    end
    % go over the ei's neighbours on v2's side
    for ej=Vtx2Edge{v2},
    end
end

%--------------------------------------------------
function [a]=formRowA(c,e,P,Node,Edge2Vtx,Cell2Edge)
% form one row of the matrix A given c=Tg and e=F in the 
% notation of DiPietro
% see eq. (2.11)
xTg = P(c,:);
ce  = find(abs(Cell2Edge{c})==e);
% FIXIT: a lot of this data can be precomputed and stored for efficiency
if(any(Edge2Cell(e,:)==0))
    % boundary edge: find edge center (average columnwise)
    xF = mean(Node(Edge2Vtx(e,:),:),1);
    a  = (xF-xTg)/dF{Tg}(ce);
else
    % interior edge: find the neighbouring element
    cn = setdiff(Edge2Cell(e,:),c);
    xT = P(cn,:);
    a  = (xT-xTg)/dF{Tg}(ce);
end
